@@ -24,13 +24,13 @@
 
 #include <config-kmountpoint.h>
 
-#include <QtCore/QFile>
-#include <QtCore/QTextStream>
+#include <QDir>
+#include <QFile>
+#include <QTextStream>
 #include <QFileInfo>
 
 #ifdef Q_OS_WIN
 #include <qt_windows.h>
-#include <QDir>
 #endif
 
 #ifdef Q_OS_WIN
@@ -65,17 +65,6 @@ static const Qt::CaseSensitivity cs = Qt::CaseSensitive;
 #if HAVE_FSTAB_H
 #include <fstab.h>
 #endif
-#if defined(_AIX)
-#include <sys/mntctl.h>
-#include <sys/vmount.h>
-#include <sys/vfs.h>
-/* AIX does not prototype mntctl anywhere that I can find */
-#ifndef mntctl
-extern "C" int mntctl(int command, int size, void *buffer);
-#endif
-extern "C" struct vfs_ent *getvfsbytype(int vfsType);
-extern "C" void endvfsent();
-#endif
 
 #if ! HAVE_GETMNTINFO
 # ifdef _PATH_MOUNTED
@@ -125,7 +114,6 @@ KMountPoint::~KMountPoint()
 // There are (at least) four kind of APIs:
 // setmntent + getmntent + struct mntent (linux...)
 //             getmntent + struct mnttab
-// mntctl                + struct vmount (AIX)
 // getmntinfo + struct statfs&flags (BSD 4.4 and friends)
 // getfsent + char* (BSD 4.3 and friends)
 
@@ -134,7 +122,7 @@ KMountPoint::~KMountPoint()
 #define ENDMNTENT endmntent
 #define STRUCT_MNTENT struct mntent *
 #define STRUCT_SETMNTENT FILE *
-#define GETMNTENT(file, var) ((var = getmntent(file)) != 0)
+#define GETMNTENT(file, var) ((var = getmntent(file)) != nullptr)
 #define MOUNTPOINT(var) var->mnt_dir
 #define MOUNTTYPE(var) var->mnt_type
 #define MOUNTOPTIONS(var) var->mnt_opts
@@ -144,43 +132,24 @@ KMountPoint::~KMountPoint()
 #define ENDMNTENT fclose
 #define STRUCT_MNTENT struct mnttab
 #define STRUCT_SETMNTENT FILE *
-#define GETMNTENT(file, var) (getmntent(file, &var) == 0)
+#define GETMNTENT(file, var) (getmntent(file, &var) == nullptr)
 #define MOUNTPOINT(var) var.mnt_mountp
 #define MOUNTTYPE(var) var.mnt_fstype
 #define MOUNTOPTIONS(var) var.mnt_mntopts
 #define FSNAME(var) var.mnt_special
 #endif
 
-/**
- * When using supermount, the device name is in the options field
- * as dev=/my/device
- */
-static QString devNameFromOptions(const QStringList &options)
-{
-    // Search options to find the device name
-    for (QStringList::ConstIterator it = options.begin(); it != options.end(); ++it) {
-        if ((*it).startsWith(QLatin1String("dev="))) {
-            return (*it).mid(4);
-        }
-    }
-    return QStringLiteral("none");
-}
-
 void KMountPoint::Private::finalizePossibleMountPoint(DetailsNeededFlags infoNeeded)
 {
-    if (mountType == QLatin1String("supermount")) {
-        mountedFrom = devNameFromOptions(mountOptions);
-    }
-
     if (mountedFrom.startsWith(QLatin1String("UUID="))) {
-        const QString uuid = mountedFrom.mid(5);
+        const QStringRef uuid = mountedFrom.midRef(5);
         const QString potentialDevice = QFile::symLinkTarget(QLatin1String("/dev/disk/by-uuid/") + uuid);
         if (QFile::exists(potentialDevice)) {
             mountedFrom = potentialDevice;
         }
     }
     if (mountedFrom.startsWith(QLatin1String("LABEL="))) {
-        const QString label = mountedFrom.mid(6);
+        const QStringRef label = mountedFrom.midRef(6);
         const QString potentialDevice = QFile::symLinkTarget(QLatin1String("/dev/disk/by-label/") + label);
         if (QFile::exists(potentialDevice)) {
             mountedFrom = potentialDevice;
@@ -226,9 +195,7 @@ KMountPoint::List KMountPoint::possibleMountPoints(DetailsNeededFlags infoNeeded
         mp->d->mountPoint = QFile::decodeName(MOUNTPOINT(fe));
         mp->d->mountType = QFile::decodeName(MOUNTTYPE(fe));
 
-        //Devices using supermount have their device names in the mount options
-        //instead of the device field. That's why we need to read the mount options
-        if (infoNeeded & NeedMountOptions || (mp->d->mountType == QLatin1String("supermount"))) {
+        if (infoNeeded & NeedMountOptions) {
             QString options = QFile::decodeName(MOUNTOPTIONS(fe));
             mp->d->mountOptions = options.split(QLatin1Char(','));
         }
@@ -332,69 +299,7 @@ KMountPoint::List KMountPoint::currentMountPoints(DetailsNeededFlags infoNeeded)
         result.append(mp);
     }
 
-#elif defined(_AIX)
-
-    struct vmount *mntctl_buffer;
-    struct vmount *vm;
-    char *mountedfrom;
-    char *mountedto;
-    int fsname_len, num;
-    int buf_sz = 4096;
-
-    mntctl_buffer = (struct vmount *)malloc(buf_sz);
-    num = mntctl(MCTL_QUERY, buf_sz, mntctl_buffer);
-    if (num == 0) {
-        buf_sz = *(int *)mntctl_buffer;
-        free(mntctl_buffer);
-        mntctl_buffer = (struct vmount *)malloc(buf_sz);
-        num = mntctl(MCTL_QUERY, buf_sz, mntctl_buffer);
-    }
-
-    if (num > 0) {
-        /* iterate through items in the vmount structure: */
-        vm = (struct vmount *)mntctl_buffer;
-        for (; num > 0; --num) {
-            /* get the name of the mounted file systems: */
-            fsname_len = vmt2datasize(vm, VMT_STUB);
-            mountedto     = (char *)malloc(fsname_len + 1);
-            mountedto[fsname_len] = '\0';
-            strncpy(mountedto, (char *)vmt2dataptr(vm, VMT_STUB), fsname_len);
-
-            fsname_len = vmt2datasize(vm, VMT_OBJECT);
-            mountedfrom     = (char *)malloc(fsname_len + 1);
-            mountedfrom[fsname_len] = '\0';
-            strncpy(mountedfrom, (char *)vmt2dataptr(vm, VMT_OBJECT), fsname_len);
-
-            /* Look up the string for the file system type,
-                 * as listed in /etc/vfs.
-                 * ex.: nfs,jfs,afs,cdrfs,sfs,cachefs,nfs3,autofs
-                 */
-            struct vfs_ent *ent = getvfsbytype(vm->vmt_gfstype);
-
-            KMountPoint *mp = new KMountPoint;
-            mp->d->mountedFrom = QFile::decodeName(mountedfrom);
-            mp->d->mountPoint = QFile::decodeName(mountedto);
-            mp->d->mountType = QFile::decodeName(ent->vfsent_name);
-
-            free(mountedfrom);
-            free(mountedto);
-
-            if (infoNeeded & NeedMountOptions) {
-                // TODO
-            }
-
-            mp->d->finalizeCurrentMountPoint(infoNeeded);
-            result.append(mp);
-
-            /* goto the next vmount structure: */
-            vm = (struct vmount *)((char *)vm + vm->vmt_length);
-        }
-
-        endvfsent();
-    }
-
-    free(mntctl_buffer);
-#elif defined(Q_OS_WIN) && !defined(_WIN32_WCE)
+#elif defined(Q_OS_WIN)
     //nothing fancy with infoNeeded but it gets the job done
     DWORD bits = GetLogicalDrives();
     if (!bits) {
@@ -409,12 +314,7 @@ KMountPoint::List KMountPoint::currentMountPoints(DetailsNeededFlags infoNeeded)
         }
     }
 
-#elif defined(_WIN32_WCE)
-    Ptr mp(new KMountPoint);
-    mp->d->mountPoint = QString("/");
-    result.append(mp);
-
-#else
+#elif !defined(Q_OS_ANDROID)
     STRUCT_SETMNTENT mnttab;
     if ((mnttab = SETMNTENT(MNTTAB, "r")) == nullptr) {
         return result;
@@ -428,12 +328,29 @@ KMountPoint::List KMountPoint::currentMountPoints(DetailsNeededFlags infoNeeded)
         mp->d->mountPoint = QFile::decodeName(MOUNTPOINT(fe));
         mp->d->mountType = QFile::decodeName(MOUNTTYPE(fe));
 
-        //Devices using supermount have their device names in the mount options
-        //instead of the device field. That's why we need to read the mount options
-        if (infoNeeded & NeedMountOptions || (mp->d->mountType == QLatin1String("supermount"))) {
+        if (infoNeeded & NeedMountOptions) {
             QString options = QFile::decodeName(MOUNTOPTIONS(fe));
             mp->d->mountOptions = options.split(QLatin1Char(','));
         }
+
+        // Resolve gvfs mountpoints
+        if (mp->d->mountedFrom == QLatin1String("gvfsd-fuse")) {
+            const QDir gvfsDir(mp->d->mountPoint);
+            const QStringList mountDirs = gvfsDir.entryList(QDir::Dirs | QDir::NoDotAndDotDot);
+            for (const auto &mountDir : mountDirs) {
+                const QString type = mountDir.section(QLatin1Char(':'), 0, 0);
+                if (type.isEmpty()) {
+                    continue;
+                }
+
+                Ptr gvfsmp(new KMountPoint);
+                gvfsmp->d->mountedFrom = mp->d->mountedFrom;
+                gvfsmp->d->mountPoint = mp->d->mountPoint + QLatin1Char('/') + mountDir;
+                gvfsmp->d->mountType = type;
+                result.append(gvfsmp);
+            }
+        }
+
         mp->d->finalizeCurrentMountPoint(infoNeeded);
 
         result.append(mp);
@@ -547,7 +464,10 @@ bool KMountPoint::testFileSystemFlag(FileSystemFlag flag) const
     const bool isNtfs = d->mountType.contains(QLatin1String("fuse.ntfs")) || d->mountType.contains(QLatin1String("fuseblk.ntfs"))
                         // fuseblk could really be anything. But its most common use is for NTFS mounts, these days.
                         || d->mountType == QLatin1String("fuseblk");
-    const bool isSmb = d->mountType == QLatin1String("cifs") || d->mountType == QLatin1String("smbfs");
+    const bool isSmb = d->mountType == QLatin1String("cifs")
+                    || d->mountType == QLatin1String("smbfs")
+                    // gvfs-fuse mounted SMB share
+                    || d->mountType == QLatin1String("smb-share");
 
     switch (flag)  {
     case SupportsChmod:
