@@ -26,11 +26,12 @@
 
 #include <QDebug>
 #include <QUrl>
-#include <QtCore/QStringList>
-#include <QtNetwork/QSslKey>
-#include <QtNetwork/QSslCipher>
-#include <QtNetwork/QHostAddress>
-#include <QtNetwork/QNetworkProxy>
+#include <QStringList>
+#include <QSslKey>
+#include <QSslCipher>
+#include <QHostAddress>
+#include <QNetworkProxy>
+#include <QAuthenticator>
 
 static KTcpSocket::SslVersion kSslVersionFromQ(QSsl::SslProtocol protocol)
 {
@@ -45,6 +46,10 @@ static KTcpSocket::SslVersion kSslVersionFromQ(QSsl::SslProtocol protocol)
         return KTcpSocket::TlsV1_1;
     case QSsl::TlsV1_2:
         return KTcpSocket::TlsV1_2;
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 12, 0))
+    case QSsl::TlsV1_3:
+        return KTcpSocket::TlsV1_3;
+#endif
     case QSsl::AnyProtocol:
         return KTcpSocket::AnySslVersion;
     case QSsl::TlsV1SslV3:
@@ -66,6 +71,9 @@ static QSsl::SslProtocol qSslProtocolFromK(KTcpSocket::SslVersion sslVersion)
     KTcpSocket::SslVersions validVersions(KTcpSocket::SslV2 | KTcpSocket::SslV3 | KTcpSocket::TlsV1);
     validVersions |= KTcpSocket::TlsV1_1;
     validVersions |= KTcpSocket::TlsV1_2;
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 12, 0))
+    validVersions |= KTcpSocket::TlsV1_3;
+#endif
     validVersions |= KTcpSocket::TlsV1SslV3;
     validVersions |= KTcpSocket::SecureProtocols;
 
@@ -84,6 +92,10 @@ static QSsl::SslProtocol qSslProtocolFromK(KTcpSocket::SslVersion sslVersion)
         return QSsl::TlsV1_1;
     case KTcpSocket::TlsV1_2:
         return QSsl::TlsV1_2;
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 12, 0))
+    case KTcpSocket::TlsV1_3:
+        return QSsl::TlsV1_3;
+#endif
     case KTcpSocket::TlsV1SslV3:
         return QSsl::TlsV1SslV3;
     case KTcpSocket::SecureProtocols:
@@ -108,6 +120,10 @@ static QString protocolString(QSsl::SslProtocol protocol)
         return QStringLiteral("TLSv1.1");
     case QSsl::TlsV1_2:
         return QStringLiteral("TLSv1.2");
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 12, 0))
+    case QSsl::TlsV1_3:
+        return QStringLiteral("TLSv1.3");
+#endif
     default:
         return QStringLiteral("Unknown");;
     }
@@ -270,7 +286,7 @@ QSslCertificate KSslError::certificate() const
 class KTcpSocketPrivate
 {
 public:
-    KTcpSocketPrivate(KTcpSocket *qq)
+    explicit KTcpSocketPrivate(KTcpSocket *qq)
         : q(qq),
           certificatesLoaded(false),
           emittedReadyRead(false)
@@ -358,6 +374,7 @@ public:
         q->setErrorString(sock.errorString());
         q->showSslErrors(); //H4X
         QList<KSslError> kErrors;
+        kErrors.reserve(errors.size());
         foreach (const QSslError &e, errors) {
             kErrors.append(KSslError(e));
         }
@@ -409,22 +426,22 @@ KTcpSocket::KTcpSocket(QObject *parent)
 {
     d->advertisedSslVersion = SslV3;
 
-    connect(&d->sock, SIGNAL(aboutToClose()), this, SIGNAL(aboutToClose()));
-    connect(&d->sock, SIGNAL(bytesWritten(qint64)), this, SIGNAL(bytesWritten(qint64)));
-    connect(&d->sock, SIGNAL(encryptedBytesWritten(qint64)), this, SIGNAL(encryptedBytesWritten(qint64)));
+    connect(&d->sock, &QIODevice::aboutToClose, this, &QIODevice::aboutToClose);
+    connect(&d->sock, &QIODevice::bytesWritten, this, &QIODevice::bytesWritten);
+    connect(&d->sock, &QSslSocket::encryptedBytesWritten, this, &KTcpSocket::encryptedBytesWritten);
     connect(&d->sock, SIGNAL(readyRead()), this, SLOT(reemitReadyRead()));
-    connect(&d->sock, SIGNAL(connected()), this, SIGNAL(connected()));
-    connect(&d->sock, SIGNAL(encrypted()), this, SIGNAL(encrypted()));
-    connect(&d->sock, SIGNAL(disconnected()), this, SIGNAL(disconnected()));
+    connect(&d->sock, &QAbstractSocket::connected, this, &KTcpSocket::connected);
+    connect(&d->sock, &QSslSocket::encrypted, this, &KTcpSocket::encrypted);
+    connect(&d->sock, &QAbstractSocket::disconnected, this, &KTcpSocket::disconnected);
 #ifndef QT_NO_NETWORKPROXY
-    connect(&d->sock, SIGNAL(proxyAuthenticationRequired(QNetworkProxy,QAuthenticator*)),
-            this, SIGNAL(proxyAuthenticationRequired(QNetworkProxy,QAuthenticator*)));
+    connect(&d->sock, &QAbstractSocket::proxyAuthenticationRequired,
+            this, &KTcpSocket::proxyAuthenticationRequired);
 #endif
     connect(&d->sock, SIGNAL(error(QAbstractSocket::SocketError)),
             this, SLOT(reemitSocketError(QAbstractSocket::SocketError)));
     connect(&d->sock, SIGNAL(sslErrors(QList<QSslError>)),
             this, SLOT(reemitSslErrors(QList<QSslError>)));
-    connect(&d->sock, SIGNAL(hostFound()), this, SIGNAL(hostFound()));
+    connect(&d->sock, &QAbstractSocket::hostFound, this, &KTcpSocket::hostFound);
     connect(&d->sock, SIGNAL(stateChanged(QAbstractSocket::SocketState)),
             this, SLOT(reemitStateChanged(QAbstractSocket::SocketState)));
     connect(&d->sock, SIGNAL(modeChanged(QSslSocket::SslMode)),
@@ -552,8 +569,10 @@ QList<KSslError> KTcpSocket::sslErrors() const
     //### pretty slow; also consider throwing out duplicate error codes. We may get
     //    duplicates even though there were none in the original list because KSslError
     //    has a smallest common denominator range of SSL error codes.
+    const auto qsslErrors = d->sock.sslErrors();
     QList<KSslError> ret;
-    foreach (const QSslError &e, d->sock.sslErrors()) {
+    ret.reserve(qsslErrors.size());
+    for (const QSslError &e : qsslErrors) {
         ret.append(KSslError(e));
     }
     return ret;
@@ -710,6 +729,7 @@ void KTcpSocket::setCiphers(const QList<KSslCipher> &ciphers)
 {
     d->ciphers = ciphers;
     QList<QSslCipher> cl;
+    cl.reserve(d->ciphers.size());
     foreach (const KSslCipher &c, d->ciphers) {
         cl.append(d->ccc.converted(c));
     }
@@ -1003,7 +1023,7 @@ QString KSslCipher::digestMethod() const
     } else if (d->name.endsWith(QLatin1String("MD5"))) {
         return QStringLiteral("MD5");
     } else {
-        return QStringLiteral("");    // ## probably QString() is enough
+        return QString();
     }
 }
 
@@ -1027,6 +1047,7 @@ QList<KSslCipher> KSslCipher::supportedCiphers()
 {
     QList<KSslCipher> ret;
     QList<QSslCipher> candidates = QSslSocket::supportedCiphers();
+    ret.reserve(candidates.size());
     foreach (const QSslCipher &c, candidates) {
         ret.append(KSslCipher(c));
     }
@@ -1059,7 +1080,9 @@ KSslErrorUiData::KSslErrorUiData(const QSslSocket *socket)
     d->certificateChain = socket->peerCertificateChain();
 
     // See KTcpSocket::sslErrors()
-    foreach (const QSslError &e, socket->sslErrors()) {
+    const auto qsslErrors = socket->sslErrors();
+    d->sslErrors.reserve(qsslErrors.size());
+    for (const QSslError &e : qsslErrors) {
         d->sslErrors.append(KSslError(e));
     }
 
