@@ -81,10 +81,10 @@ public:
     virtual ~KDirOperatorIconView();
 
 protected:
-    QStyleOptionViewItem viewOptions() const Q_DECL_OVERRIDE;
-    void dragEnterEvent(QDragEnterEvent *event) Q_DECL_OVERRIDE;
-    void mousePressEvent(QMouseEvent *event) Q_DECL_OVERRIDE;
-    void wheelEvent(QWheelEvent *event) Q_DECL_OVERRIDE;
+    QStyleOptionViewItem viewOptions() const override;
+    void dragEnterEvent(QDragEnterEvent *event) override;
+    void mousePressEvent(QMouseEvent *event) override;
+    void wheelEvent(QWheelEvent *event) override;
 
 private:
     KDirOperator *ops;
@@ -170,7 +170,7 @@ void KDirOperator::keyPressEvent(QKeyEvent *e)
 class Q_DECL_HIDDEN KDirOperator::Private
 {
 public:
-    Private(KDirOperator *parent);
+    explicit Private(KDirOperator *parent);
     ~Private();
 
     enum InlinePreviewState {
@@ -232,7 +232,7 @@ public:
     int iconSizeForViewType(QAbstractItemView *itemView) const;
 
     // private members
-    KDirOperator *parent;
+    KDirOperator * const parent;
     QStack<QUrl *> backStack;   ///< Contains all URLs you can reach with the back button.
     QStack<QUrl *> forwardStack; ///< Contains all URLs you can reach with the forward button.
 
@@ -368,7 +368,7 @@ KDirOperator::KDirOperator(const QUrl &_url, QWidget *parent) :
 
     if (_url.isEmpty()) { // no dir specified -> current dir
         QString strPath = QDir::currentPath();
-        strPath.append(QChar('/'));
+        strPath.append(QLatin1Char('/'));
         d->currUrl = QUrl::fromLocalFile(strPath);
     } else {
         d->currUrl = _url;
@@ -377,8 +377,8 @@ KDirOperator::KDirOperator(const QUrl &_url, QWidget *parent) :
         }
 
         QString path = d->currUrl.path();
-        if (!path.endsWith('/')) {
-            path.append('/'); // make sure we have a trailing slash!
+        if (!path.endsWith(QLatin1Char('/'))) {
+            path.append(QLatin1Char('/')); // make sure we have a trailing slash!
         }
         d->currUrl.setPath(path);
     }
@@ -389,8 +389,8 @@ KDirOperator::KDirOperator(const QUrl &_url, QWidget *parent) :
     setLayoutDirection(Qt::LeftToRight);
     setDirLister(new KDirLister());
 
-    connect(&d->completion, SIGNAL(match(QString)),
-            SLOT(slotCompletionMatch(QString)));
+    connect(&d->completion, &KCompletion::match,
+            this, &KDirOperator::slotCompletionMatch);
 
     d->progressBar = new QProgressBar(this);
     d->progressBar->setObjectName(QStringLiteral("d->progressBar"));
@@ -437,12 +437,12 @@ bool KDirOperator::isRoot() const
     if (url().isLocalFile()) {
         const QString path = url().toLocalFile();
         if (path.length() == 3) {
-            return (path[0].isLetter() && path[1] == ':' && path[2] == '/');
+            return (path[0].isLetter() && path[1] == QLatin1Char(':') && path[2] == QLatin1Char('/'));
         }
         return false;
     } else
 #endif
-        return url().path() == QString(QLatin1Char('/'));
+        return url().path() == QLatin1String("/");
 }
 
 KDirLister *KDirOperator::dirLister() const
@@ -739,7 +739,7 @@ bool KDirOperator::mkdir(const QString &directory, bool enterDirectory)
     bool exists = false;
     QUrl folderurl(d->currUrl);
 
-    const QStringList dirs = directory.split('/', QString::SkipEmptyParts);
+    const QStringList dirs = directory.split(QLatin1Char('/'), QString::SkipEmptyParts);
     QStringList::ConstIterator it = dirs.begin();
 
     for (; it != dirs.end(); ++it) {
@@ -994,7 +994,7 @@ void KDirOperator::setUrl(const QUrl &_newurl, bool clearforward)
     if (!_newurl.isValid()) {
         newurl = QUrl::fromLocalFile(QDir::homePath());
     } else {
-        newurl = _newurl;
+        newurl = _newurl.adjusted(QUrl::NormalizePathSegments);
     }
 
     if (!newurl.path().isEmpty() && !newurl.path().endsWith(QLatin1Char('/'))) {
@@ -1225,7 +1225,8 @@ QUrl KDirOperator::url() const
 
 void KDirOperator::cdUp()
 {
-    QUrl tmp(d->currUrl);
+    // Allow /d/c// to go up to /d/ instead of /d/c/
+    QUrl tmp(d->currUrl.adjusted(QUrl::NormalizePathSegments));
     setUrl(tmp.resolved(QUrl(QStringLiteral(".."))), true);
 }
 
@@ -1392,7 +1393,7 @@ bool KDirOperator::Private::checkPreviewInternal() const
     }
 
     QStringList mimeTypes = dirLister->mimeFilters();
-    const QStringList nameFilter = dirLister->nameFilter().split(' ', QString::SkipEmptyParts);
+    const QStringList nameFilter = dirLister->nameFilter().split(QLatin1Char(' '), QString::SkipEmptyParts);
     QMimeDatabase db;
 
     if (mimeTypes.isEmpty() && nameFilter.isEmpty() && !supported.isEmpty()) {
@@ -1874,31 +1875,33 @@ void KDirOperator::setupActions()
     d->actionCollection->addAction(QStringLiteral("trash"), trash);
     trash->setIcon(QIcon::fromTheme(QStringLiteral("user-trash")));
     trash->setShortcut(Qt::Key_Delete);
-    connect(trash, SIGNAL(triggered(bool)), SLOT(trashSelected()));
+    connect(trash, &QAction::triggered, this, &KDirOperator::trashSelected);
 
     QAction *action = new QAction(i18n("Delete"), this);
     d->actionCollection->addAction(QStringLiteral("delete"), action);
     action->setIcon(QIcon::fromTheme(QStringLiteral("edit-delete")));
     action->setShortcut(Qt::SHIFT + Qt::Key_Delete);
-    connect(action, SIGNAL(triggered(bool)), this, SLOT(deleteSelected()));
+    connect(action, &QAction::triggered, this, &KDirOperator::deleteSelected);
 
     // the sort menu actions
     KActionMenu *sortMenu = new KActionMenu(i18n("Sorting"), this);
+    sortMenu->setIcon(QIcon::fromTheme(QStringLiteral("view-sort")));
+    sortMenu->setDelayed(false);
     d->actionCollection->addAction(QStringLiteral("sorting menu"),  sortMenu);
 
-    KToggleAction *byNameAction = new KToggleAction(i18n("By Name"), this);
+    KToggleAction *byNameAction = new KToggleAction(i18n("Sort by Name"), this);
     d->actionCollection->addAction(QStringLiteral("by name"), byNameAction);
     connect(byNameAction, SIGNAL(triggered(bool)), this, SLOT(_k_slotSortByName()));
 
-    KToggleAction *bySizeAction = new KToggleAction(i18n("By Size"), this);
+    KToggleAction *bySizeAction = new KToggleAction(i18n("Sort by Size"), this);
     d->actionCollection->addAction(QStringLiteral("by size"), bySizeAction);
     connect(bySizeAction, SIGNAL(triggered(bool)), this, SLOT(_k_slotSortBySize()));
 
-    KToggleAction *byDateAction = new KToggleAction(i18n("By Date"), this);
+    KToggleAction *byDateAction = new KToggleAction(i18n("Sort by Date"), this);
     d->actionCollection->addAction(QStringLiteral("by date"), byDateAction);
     connect(byDateAction, SIGNAL(triggered(bool)), this, SLOT(_k_slotSortByDate()));
 
-    KToggleAction *byTypeAction = new KToggleAction(i18n("By Type"), this);
+    KToggleAction *byTypeAction = new KToggleAction(i18n("Sort by Type"), this);
     d->actionCollection->addAction(QStringLiteral("by type"), byTypeAction);
     connect(byTypeAction, SIGNAL(triggered(bool)), this, SLOT(_k_slotSortByType()));
 
@@ -2060,6 +2063,7 @@ void KDirOperator::setupMenu(int whichActions)
 
     if (whichActions & ViewActions) {
         d->actionMenu->addAction(d->actionCollection->action(QStringLiteral("view menu")));
+        d->actionMenu->addAction(d->actionCollection->action(QStringLiteral("reload")));
         d->actionMenu->addSeparator();
     }
 
@@ -2149,7 +2153,7 @@ void KDirOperator::readConfig(const KConfigGroup &configGroup)
     d->updateSorting(sorting);
 
     if (d->inlinePreviewState == Private::NotForced) {
-        d->showPreviews = configGroup.readEntry(QStringLiteral("Previews"), false);
+        d->showPreviews = configGroup.readEntry(QStringLiteral("Show Inline Previews"), true);
     }
     QStyleOptionViewItem::Position pos = (QStyleOptionViewItem::Position) configGroup.readEntry(QStringLiteral("Decoration position"), (int) QStyleOptionViewItem::Left);
     setDecorationPosition(pos);
@@ -2213,7 +2217,7 @@ void KDirOperator::writeConfig(KConfigGroup &configGroup)
     configGroup.writeEntry(QStringLiteral("View Style"), style);
 
     if (d->inlinePreviewState == Private::NotForced) {
-        configGroup.writeEntry(QStringLiteral("Previews"), d->showPreviews);
+        configGroup.writeEntry(QStringLiteral("Show Inline Previews"), d->showPreviews);
         if (qobject_cast<QListView *>(d->itemView)) {
             configGroup.writeEntry(QStringLiteral("listViewIconSize"), d->iconsZoom);
         } else {
@@ -2249,6 +2253,8 @@ void KDirOperator::resizeEvent(QResizeEvent *)
         // might be reparented into a statusbar
         d->progressBar->move(2, height() - d->progressBar->height() - 2);
     }
+
+    d->updateListViewGrid();
 }
 
 void KDirOperator::setOnlyDoubleClickSelectsFiles(bool enable)
@@ -2390,7 +2396,7 @@ void KDirOperator::Private::_k_slotSelectionChanged()
         KFileItem nullItem;
         parent->highlightFile(nullItem);
     } else {
-        KFileItem selectedItem = parent->selectedItems().first();
+        const KFileItem selectedItem = parent->selectedItems().constFirst();
         parent->highlightFile(selectedItem);
     }
 }
@@ -2583,12 +2589,26 @@ void KDirOperator::Private::updateListViewGrid()
         }
     } else {
         const QFontMetrics metrics(itemView->viewport()->font());
-        int size = itemView->iconSize().height() + metrics.height() * 2;
-        // some heuristics for good looking. let's guess width = height * (3 / 2) is nice
-        view->setGridSize(QSize(size * (3.0 / 2.0), size + metrics.height()));
+
+        const int height = itemView->iconSize().height() + metrics.height() * 2.5;
+        const int minWidth = qMax(height, metrics.height() * 5);
+
+        const int scrollBarWidth = itemView->verticalScrollBar()->sizeHint().width();
+
+        // Subtract 1 px to prevent flickering when resizing the window
+        // For Oxygen a column is missing after showing the dialog without resizing it,
+        // therefore subtract 4 more (scaled) pixels
+        const int viewPortWidth = itemView->contentsRect().width() - scrollBarWidth - 1 - 4 * itemView->devicePixelRatioF();
+        const int itemsInRow = qMax(1, viewPortWidth / minWidth);
+        const int remainingWidth = viewPortWidth - (minWidth * itemsInRow);
+        const int width = minWidth + (remainingWidth / itemsInRow);
+        
+        const QSize itemSize(width, height);
+
+        view->setGridSize(itemSize);
         KFileItemDelegate *delegate = qobject_cast<KFileItemDelegate *>(view->itemDelegate());
         if (delegate) {
-            delegate->setMaximumSize(QSize(size * (3.0 / 2.0), size + metrics.height()));
+            delegate->setMaximumSize(itemSize);
         }
     }
 }
