@@ -31,7 +31,10 @@
 class KNameAndUrlInputDialogPrivate
 {
 public:
-    KNameAndUrlInputDialogPrivate(KNameAndUrlInputDialog *qq) : m_fileNameEdited(false), q(qq) {}
+    explicit KNameAndUrlInputDialogPrivate(KNameAndUrlInputDialog *qq)
+        : m_fileNameEdited(false)
+        , q(qq)
+    {}
 
     void _k_slotNameTextChanged(const QString &);
     void _k_slotURLTextChanged(const QString &);
@@ -51,7 +54,7 @@ public:
 
     QDialogButtonBox *m_buttonBox;
 
-    KNameAndUrlInputDialog *q;
+    KNameAndUrlInputDialog * const q;
 };
 
 KNameAndUrlInputDialog::KNameAndUrlInputDialog(const QString &nameLabel, const QString &urlLabel, const QUrl &startDir, QWidget *parent)
@@ -85,8 +88,8 @@ KNameAndUrlInputDialog::KNameAndUrlInputDialog(const QString &nameLabel, const Q
 
     d->m_buttonBox = new QDialogButtonBox(this);
     d->m_buttonBox->setStandardButtons(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
-    connect(d->m_buttonBox, SIGNAL(accepted()), this, SLOT(accept()));
-    connect(d->m_buttonBox, SIGNAL(rejected()), this, SLOT(reject()));
+    connect(d->m_buttonBox, &QDialogButtonBox::accepted, this, &QDialog::accept);
+    connect(d->m_buttonBox, &QDialogButtonBox::rejected, this, &QDialog::reject);
     topLayout->addWidget(d->m_buttonBox);
 
     d->m_fileNameEdited = false;
