@@ -66,7 +66,7 @@ KCookieWin::KCookieWin(QWidget *parent, KHttpCookieList cookieList,
     setWindowTitle(i18n("Cookie Alert"));
     setWindowIcon(QIcon::fromTheme(QStringLiteral("preferences-web-browser-cookies")));
     // all cookies in the list should have the same window at this time, so let's take the first
-    if (cookieList.first().windowIds().count() > 0) {
+    if (!cookieList.first().windowIds().isEmpty()) {
         KWindowSystem::setMainWindow(this, cookieList.first().windowIds().first());
     } else {
         // No window associated... make sure the user notices our dialog.
@@ -77,11 +77,11 @@ KCookieWin::KCookieWin(QWidget *parent, KHttpCookieList cookieList,
     const int count = cookieList.count();
     const KHttpCookie &cookie = cookieList.first();
     QString host(cookie.host());
-    int pos = host.indexOf(':');
+    const int pos = host.indexOf(QLatin1Char(':'));
     if (pos > 0) {
         QString portNum = host.left(pos);
         host.remove(0, pos + 1);
-        host += ':';
+        host += QLatin1Char(':');
         host += portNum;
     }
 
@@ -108,12 +108,12 @@ KCookieWin::KCookieWin(QWidget *parent, KHttpCookieList cookieList,
     topLayout->addWidget(vBox1);
 
     m_detailsButton = new QPushButton;
-    m_detailsButton->setText(i18n("Details") + " >>");
+    m_detailsButton->setText(i18n("Details") + QLatin1String(" >>"));
     m_detailsButton->setIcon(QIcon::fromTheme(QStringLiteral("dialog-information")));
 #ifndef QT_NO_TOOLTIP
     m_detailsButton->setToolTip(i18n("See or modify the cookie information"));
 #endif
-    connect(m_detailsButton, SIGNAL(clicked()), this, SLOT(slotToggleDetails()));
+    connect(m_detailsButton, &QAbstractButton::clicked, this, &KCookieWin::slotToggleDetails);
 
     QPushButton *sessionOnlyButton = new QPushButton;
     sessionOnlyButton->setText(i18n("Accept for this &session"));
@@ -121,7 +121,7 @@ KCookieWin::KCookieWin(QWidget *parent, KHttpCookieList cookieList,
 #ifndef QT_NO_TOOLTIP
     sessionOnlyButton->setToolTip(i18n("Accept cookie(s) until the end of the current session"));
 #endif
-    connect(sessionOnlyButton, SIGNAL(clicked()), this, SLOT(slotSessionOnlyClicked()));
+    connect(sessionOnlyButton, &QAbstractButton::clicked, this, &KCookieWin::slotSessionOnlyClicked);
 
     QDialogButtonBox *buttonBox = new QDialogButtonBox(this);
     buttonBox->addButton(m_detailsButton, QDialogButtonBox::ActionRole);
@@ -130,10 +130,10 @@ KCookieWin::KCookieWin(QWidget *parent, KHttpCookieList cookieList,
     buttonBox->setStandardButtons(QDialogButtonBox::Yes | QDialogButtonBox::No);
     QPushButton *but = buttonBox->button(QDialogButtonBox::Yes);
     but->setText(i18n("&Accept"));
-    connect(but, SIGNAL(clicked(bool)), SLOT(accept()));
+    connect(but, &QAbstractButton::clicked, this, &QDialog::accept);
     but = buttonBox->button(QDialogButtonBox::No);
     but->setText(i18n("&Reject"));
-    connect(but, SIGNAL(clicked(bool)), SLOT(reject()));
+    connect(but, &QAbstractButton::clicked, this, &QDialog::reject);
 
     topLayout->addWidget(buttonBox);
 
@@ -253,7 +253,7 @@ KCookieAdvice KCookieWin::advice(KCookieJar *cookiejar, const KHttpCookie &cooki
     return advice;
 }
 
-KCookieDetail::KCookieDetail(KHttpCookieList cookieList, int cookieCount,
+KCookieDetail::KCookieDetail(const KHttpCookieList &cookieList, int cookieCount,
                              QWidget *parent)
     : QGroupBox(parent)
 {
@@ -309,7 +309,7 @@ KCookieDetail::KCookieDetail(KHttpCookieList cookieList, int cookieCount,
         QPushButton *btnNext = new QPushButton(i18nc("Next cookie", "&Next >>"), this);
         btnNext->setFixedSize(btnNext->sizeHint());
         grid->addWidget(btnNext, 8, 0, 1, 2);
-        connect(btnNext, SIGNAL(clicked()), SLOT(slotNextCookie()));
+        connect(btnNext, &QAbstractButton::clicked, this, &KCookieDetail::slotNextCookie);
 #ifndef QT_NO_TOOLTIP
         btnNext->setToolTip(i18n("Show details of the next cookie"));
 #endif
@@ -378,10 +378,10 @@ void KCookieWin::slotToggleDetails()
     const QString baseText = i18n("Details");
 
     if (!m_detailView->isHidden()) {
-        m_detailsButton->setText(baseText + " >>");
+        m_detailsButton->setText(baseText + QLatin1String(" >>"));
         m_detailView->hide();
     } else {
-        m_detailsButton->setText(baseText + " <<");
+        m_detailsButton->setText(baseText + QLatin1String(" <<"));
         m_detailView->show();
     }
 }
