@@ -30,8 +30,9 @@
 #include <kconfiggroup.h>
 #include <ksharedconfig.h>
 
-#include <QtCore/QFile>
-#include <QtDBus/QtDBus>
+#include <QDBusConnection>
+#include <QDBusMessage>
+#include <QFile>
 #include <QSortFilterProxyModel>
 
 
@@ -40,7 +41,7 @@
 
 ProvidersModel::~ProvidersModel()
 {
-  qDeleteAll(m_providers);
+
 }
 
 QVariant ProvidersModel::headerData(int section, Qt::Orientation orientation, int role ) const
@@ -97,7 +98,7 @@ QVariant ProvidersModel::data(const QModelIndex& index, int role) const
       if (index.column()==Name)
         return m_providers.at(index.row())->name();
       if (index.column()==Shortcuts)
-        return m_providers.at(index.row())->keys().join(QStringLiteral(","));
+        return m_providers.at(index.row())->keys().join(QLatin1Char(','));
     }
 
     if (role == Qt::ToolTipRole || role == Qt::WhatsThisRole)
@@ -139,15 +140,16 @@ int ProvidersModel::rowCount(const QModelIndex & parent) const
 QAbstractListModel* ProvidersModel::createListModel()
 {
   ProvidersListModel* pListModel = new ProvidersListModel(m_providers, this);
-  connect(this, SIGNAL(modelAboutToBeReset()),        pListModel, SIGNAL(modelAboutToBeReset()));
-  connect(this, SIGNAL(modelReset()),                 pListModel, SIGNAL(modelReset()));
+  connect(this, &QAbstractItemModel::modelAboutToBeReset,   pListModel, &QAbstractItemModel::modelAboutToBeReset);
+  connect(this, &QAbstractItemModel::modelReset,            pListModel, &QAbstractItemModel::modelReset);
+  // TODO: next two are private signals, does this still work? and is this needed?
   connect(this, SIGNAL(layoutAboutToBeChanged()),     pListModel, SIGNAL(modelReset()));
   connect(this, SIGNAL(layoutChanged()),              pListModel, SIGNAL(modelReset()));
-  connect(this, SIGNAL(dataChanged(QModelIndex,QModelIndex)),       pListModel, SLOT(emitDataChanged(QModelIndex,QModelIndex)));
-  connect(this, SIGNAL(rowsAboutToBeInserted(QModelIndex,int,int)), pListModel, SLOT(emitRowsAboutToBeInserted(QModelIndex,int,int)));
-  connect(this, SIGNAL(rowsAboutToBeRemoved(QModelIndex,int,int)),  pListModel, SLOT(emitRowsAboutToBeRemoved(QModelIndex,int,int)));
-  connect(this, SIGNAL(rowsInserted(QModelIndex,int,int)),          pListModel, SLOT(emitRowsInserted(QModelIndex,int,int)));
-  connect(this, SIGNAL(rowsRemoved(QModelIndex,int,int)),           pListModel, SLOT(emitRowsRemoved(QModelIndex,int,int)));
+  connect(this, &QAbstractItemModel::dataChanged,           pListModel, &ProvidersListModel::emitDataChanged);
+  connect(this, &QAbstractItemModel::rowsAboutToBeInserted, pListModel, &ProvidersListModel::emitRowsAboutToBeInserted);
+  connect(this, &QAbstractItemModel::rowsAboutToBeRemoved,  pListModel, &ProvidersListModel::emitRowsAboutToBeRemoved);
+  connect(this, &QAbstractItemModel::rowsInserted,          pListModel, &ProvidersListModel::emitRowsInserted);
+  connect(this, &QAbstractItemModel::rowsRemoved,           pListModel, &ProvidersListModel::emitRowsRemoved);
 
   return pListModel;
 }
@@ -240,22 +242,21 @@ FilterOptions::FilterOptions(const KAboutData* about, QWidget *parent)
   m_dlg.cmbDefaultEngine->setModel(wrapInProxyModel(m_providersModel->createListModel()));
 
   // Connect all the signals/slots...
-  connect(m_dlg.cbEnableShortcuts, SIGNAL(toggled(bool)), SLOT(changed()));
-  connect(m_dlg.cbEnableShortcuts, SIGNAL(toggled(bool)), SLOT(updateSearchProviderEditingButons()));
-  connect(m_dlg.cbUseSelectedShortcutsOnly, SIGNAL(toggled(bool)), SLOT(changed()));
+  connect(m_dlg.cbEnableShortcuts,  &QAbstractButton::toggled, this, QOverload<>::of(&FilterOptions::changed));
+  connect(m_dlg.cbEnableShortcuts, &QAbstractButton::toggled, this, &FilterOptions::updateSearchProviderEditingButons);
+  connect(m_dlg.cbUseSelectedShortcutsOnly,  &QAbstractButton::toggled, this, QOverload<>::of(&FilterOptions::changed));
 
-  connect(m_providersModel, SIGNAL(dataModified()), SLOT(changed()));
-  connect(m_dlg.cmbDefaultEngine, SIGNAL(currentIndexChanged(int)),  SLOT(changed()));
-  connect(m_dlg.cmbDelimiter,     SIGNAL(currentIndexChanged(int)),  SLOT(changed()));
+  connect(m_providersModel, &ProvidersModel::dataModified, this, QOverload<>::of(&FilterOptions::changed));
+  connect(m_dlg.cmbDefaultEngine, QOverload<int>::of(&QComboBox::currentIndexChanged), this, QOverload<>::of(&FilterOptions::changed));
+  connect(m_dlg.cmbDelimiter,     QOverload<int>::of(&QComboBox::currentIndexChanged), this, QOverload<>::of(&FilterOptions::changed));
 
-  connect(m_dlg.pbNew,    SIGNAL(clicked()), SLOT(addSearchProvider()));
-  connect(m_dlg.pbDelete, SIGNAL(clicked()), SLOT(deleteSearchProvider()));
-  connect(m_dlg.pbChange, SIGNAL(clicked()), SLOT(changeSearchProvider()));
-  connect(m_dlg.lvSearchProviders->selectionModel(),
-           SIGNAL(currentChanged(QModelIndex,QModelIndex)),
-           SLOT(updateSearchProviderEditingButons()));
-  connect(m_dlg.lvSearchProviders, SIGNAL(doubleClicked(QModelIndex)),SLOT(changeSearchProvider()));
-  connect(m_dlg.searchLineEdit, SIGNAL(textEdited(QString)), searchProviderModel, SLOT(setFilterFixedString(QString)));
+  connect(m_dlg.pbNew,    &QAbstractButton::clicked, this, &FilterOptions::addSearchProvider);
+  connect(m_dlg.pbDelete, &QAbstractButton::clicked, this, &FilterOptions::deleteSearchProvider);
+  connect(m_dlg.pbChange, &QAbstractButton::clicked, this, &FilterOptions::changeSearchProvider);
+  connect(m_dlg.lvSearchProviders->selectionModel(), &QItemSelectionModel::currentChanged,
+           this, &FilterOptions::updateSearchProviderEditingButons);
+  connect(m_dlg.lvSearchProviders, &QAbstractItemView::doubleClicked,this, &FilterOptions::changeSearchProvider);
+  connect(m_dlg.searchLineEdit, &QLineEdit::textEdited, searchProviderModel, &QSortFilterProxyModel::setFilterFixedString);
 }
 
 QString FilterOptions::quickHelp() const
@@ -284,7 +285,7 @@ void FilterOptions::setDefaultEngine(int index)
 
 void FilterOptions::load()
 {
-  KConfig config(KURISearchFilterEngine::self()->name() + QStringLiteral("rc"), KConfig::NoGlobals);
+  KConfig config(QString::fromUtf8(KURISearchFilterEngine::self()->name()) + QLatin1String("rc"), KConfig::NoGlobals);
   KConfigGroup group = config.group("General");
 
   const QString defaultSearchEngine = group.readEntry("DefaultWebShortcut");
@@ -326,7 +327,7 @@ void FilterOptions::setDelimiter (char sep)
 
 void FilterOptions::save()
 {
-  KConfig config(KURISearchFilterEngine::self()->name() + QStringLiteral("rc"), KConfig::NoGlobals );
+  KConfig config(QString::fromUtf8(KURISearchFilterEngine::self()->name()) + QLatin1String("rc"), KConfig::NoGlobals );
 
   KConfigGroup group = config.group("General");
   group.writeEntry("EnableWebShortcuts", m_dlg.cbEnableShortcuts->isChecked());
@@ -337,7 +338,7 @@ void FilterOptions::save()
 
   int changedProviderCount = 0;
   QList<SearchProvider*> providers = m_providersModel->providers();
-  const QString path = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + "/kservices5/searchproviders/";
+  const QString path = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1String("/kservices5/searchproviders/");
 
   Q_FOREACH(SearchProvider* provider, providers)
   {
@@ -346,10 +347,10 @@ void FilterOptions::save()
 
     changedProviderCount++;
 
-    KConfig _service(path + provider->desktopEntryName() + ".desktop", KConfig::SimpleConfig );
+    KConfig _service(path + provider->desktopEntryName() + QLatin1String(".desktop"), KConfig::SimpleConfig);
     KConfigGroup service(&_service, "Desktop Entry");
     service.writeEntry("Type", "Service");
-    service.writeEntry("ServiceTypes", "SearchProvider");
+    service.writeEntry("X-KDE-ServiceTypes", "SearchProvider");
     service.writeEntry("Name", provider->name());
     service.writeEntry("Query", provider->query());
     service.writeEntry("Keys", provider->keys());
@@ -362,13 +363,13 @@ void FilterOptions::save()
   {
     QStringList matches;
     foreach(const QString& dir, servicesDirs) {
-      QString current = dir + '/' + providerName + ".desktop";
+      QString current = dir + QLatin1Char('/') + providerName + QLatin1String(".desktop");
       if(QFile::exists(current))
         matches += current;
     }
 
     // Shouldn't happen
-    if (!matches.size())
+    if (matches.isEmpty())
       continue;
 
     changedProviderCount++;
@@ -381,10 +382,10 @@ void FilterOptions::save()
       continue;
     }
 
-    KConfig _service(path + providerName + ".desktop", KConfig::SimpleConfig );
+    KConfig _service(path + providerName + QLatin1String(".desktop"), KConfig::SimpleConfig);
     KConfigGroup service(&_service,     "Desktop Entry");
     service.writeEntry("Type",          "Service");
-    service.writeEntry("ServiceTypes",  "SearchProvider");
+    service.writeEntry("X-KDE-ServiceTypes",  "SearchProvider");
     service.writeEntry("Hidden",        true);
   }
 
