@@ -34,18 +34,18 @@
 #include <kprotocolinfo.h>
 #include <klocalizedstring.h>
 
-#include <QtCore/QUrl>
+#include <QUrl>
 #include <QNetworkCookie>
 #include <QPointer>
 #include <QWidget>
-#include <QtDBus/QDBusInterface>
-#include <QtDBus/QDBusConnection>
-#include <QtDBus/QDBusReply>
-#include <QtNetwork/QNetworkReply>
-#include <QtNetwork/QNetworkRequest>
-#include <QtNetwork/QSslCipher>
-#include <QtNetwork/QSslCertificate>
-#include <QtNetwork/QSslConfiguration>
+#include <QDBusInterface>
+#include <QDBusConnection>
+#include <QDBusReply>
+#include <QNetworkReply>
+#include <QNetworkRequest>
+#include <QSslCipher>
+#include <QSslCertificate>
+#include <QSslConfiguration>
 
 #define QL1S(x)   QLatin1String(x)
 #define QL1C(x)   QLatin1Char(x)
@@ -297,11 +297,11 @@ QNetworkReply *AccessManager::createRequest(Operation op, const QNetworkRequest
             kioJob = KIO::get(reqUrl, KIO::NoReload, KIO::HideProgressInfo);
         }
 
-        metaData.insert(QStringLiteral("CustomHTTPMethod"), method);
+        metaData.insert(QStringLiteral("CustomHTTPMethod"), QString::fromUtf8(method));
         break;
     }
     default: {
-        qCWarning(KIO_WIDGETS) << "Unsupported KIO operation requested! Defering to QNetworkAccessManager...";
+        qCWarning(KIO_WIDGETS) << "Unsupported KIO operation requested! Deferring to QNetworkAccessManager...";
         return QNetworkAccessManager::createRequest(op, req, outgoingData);
     }
     }
@@ -384,6 +384,15 @@ QNetworkReply *AccessManager::createRequest(Operation op, const QNetworkRequest
     return reply;
 }
 
+static inline
+void moveMetaData(KIO::MetaData &metaData, const QString &metaDataKey, QNetworkRequest &request, const QByteArray &requestKey)
+{
+    if (request.hasRawHeader(requestKey)) {
+        metaData.insert(metaDataKey, QString::fromUtf8(request.rawHeader(requestKey)));
+        request.setRawHeader(requestKey, QByteArray());
+    }
+}
+
 void AccessManager::AccessManagerPrivate::setMetaDataForRequest(QNetworkRequest request, KIO::MetaData &metaData)
 {
     // Add any meta data specified within request...
@@ -394,35 +403,12 @@ void AccessManager::AccessManagerPrivate::setMetaDataForRequest(QNetworkRequest
 
     metaData.insert(QStringLiteral("PropagateHttpHeader"), QStringLiteral("true"));
 
-    if (request.hasRawHeader("User-Agent")) {
-        metaData.insert(QStringLiteral("UserAgent"), request.rawHeader("User-Agent"));
-        request.setRawHeader("User-Agent", QByteArray());
-    }
-
-    if (request.hasRawHeader("Accept")) {
-        metaData.insert(QStringLiteral("accept"), request.rawHeader("Accept"));
-        request.setRawHeader("Accept", QByteArray());
-    }
-
-    if (request.hasRawHeader("Accept-Charset")) {
-        metaData.insert(QStringLiteral("Charsets"), request.rawHeader("Accept-Charset"));
-        request.setRawHeader("Accept-Charset", QByteArray());
-    }
-
-    if (request.hasRawHeader("Accept-Language")) {
-        metaData.insert(QStringLiteral("Languages"), request.rawHeader("Accept-Language"));
-        request.setRawHeader("Accept-Language", QByteArray());
-    }
-
-    if (request.hasRawHeader("Referer")) {
-        metaData.insert(QStringLiteral("referrer"), request.rawHeader("Referer"));
-        request.setRawHeader("Referer", QByteArray());
-    }
-
-    if (request.hasRawHeader("Content-Type")) {
-        metaData.insert(QStringLiteral("content-type"), request.rawHeader("Content-Type"));
-        request.setRawHeader("Content-Type", QByteArray());
-    }
+    moveMetaData(metaData, QStringLiteral("UserAgent"),    request, QByteArrayLiteral("User-Agent"));
+    moveMetaData(metaData, QStringLiteral("accept"),       request, QByteArrayLiteral("Accept"));
+    moveMetaData(metaData, QStringLiteral("Charsets"),     request, QByteArrayLiteral("Accept-Charset"));
+    moveMetaData(metaData, QStringLiteral("Languages"),    request, QByteArrayLiteral("Accept-Language"));
+    moveMetaData(metaData, QStringLiteral("referrer"),     request, QByteArrayLiteral("Referer")); //Don't try to correct spelling!
+    moveMetaData(metaData, QStringLiteral("content-type"), request, QByteArrayLiteral("Content-Type"));
 
     if (request.attribute(QNetworkRequest::AuthenticationReuseAttribute) == QNetworkRequest::Manual) {
         metaData.insert(QStringLiteral("no-preemptive-auth-reuse"), QStringLiteral("true"));
@@ -438,7 +424,7 @@ void AccessManager::AccessManagerPrivate::setMetaDataForRequest(QNetworkRequest
     Q_FOREACH (const QByteArray &key, request.rawHeaderList()) {
         const QByteArray value = request.rawHeader(key);
         if (value.length()) {
-            customHeaders << (key + QStringLiteral(": ") + value);
+            customHeaders << (QString::fromUtf8(key) + QLatin1String(": ") + QString::fromUtf8(value));
         }
     }
 
@@ -535,8 +521,8 @@ QList<QNetworkCookie> CookieJar::cookiesForUrl(const QUrl &url) const
     const QStringList cookies = cookieStr.split(QStringLiteral("; "), QString::SkipEmptyParts);
     Q_FOREACH (const QString &cookie, cookies) {
         const int index = cookie.indexOf(QL1C('='));
-        const QString name = cookie.left(index);
-        const QString value = cookie.right((cookie.length() - index - 1));
+        const QStringRef name = cookie.leftRef(index);
+        const QStringRef value = cookie.rightRef((cookie.length() - index - 1));
         cookieList << QNetworkCookie(name.toUtf8(), value.toUtf8());
         //qDebug() << "cookie: name=" << name << ", value=" << value;
     }
