@@ -20,10 +20,10 @@
 #include "kdirmodel.h"
 #include "kdirlister.h"
 #include "kfileitem.h"
-#include <kiconloader.h>
+#include "kio_widgets_debug.h"
 #include <klocalizedstring.h>
 #include <kjobuidelegate.h>
-#include <kio/copyjob.h>
+#include <kio/simplejob.h>
 #include <kio/fileundomanager.h>
 #include "joburlcache_p.h"
 #include <kurlmimedata.h>
@@ -38,6 +38,8 @@
 #include <QLocale>
 #include <qplatformdefs.h>
 
+#include <algorithm>
+
 #ifdef Q_OS_WIN
 #include <qt_windows.h>
 #endif
@@ -66,6 +68,10 @@ public:
         m_preview()
     {
     }
+    virtual ~KDirModelNode()
+    {
+        // Required, code will delete ptrs to this or a subclass.
+    }
     // m_item is KFileItem() for the root item
     const KFileItem &item() const
     {
@@ -111,7 +117,7 @@ public:
           m_childCount(KDirModel::ChildCountUnknown),
           m_populated(false)
     {}
-    ~KDirModelDirNode()
+    ~KDirModelDirNode() override
     {
         qDeleteAll(m_childNodes);
     }
@@ -142,6 +148,7 @@ public:
     // For removing all child urls from the global hash.
     void collectAllChildUrls(QList<QUrl> &urls) const
     {
+        urls.reserve(urls.size() + m_childNodes.size());
         Q_FOREACH (KDirModelNode *node, m_childNodes) {
             const KFileItem &item = node->item();
             urls.append(cleanupUrl(item.url()));
@@ -169,9 +176,9 @@ int KDirModelNode::rowNumber() const
 class KDirModelPrivate
 {
 public:
-    KDirModelPrivate(KDirModel *model)
-        : q(model), m_dirLister(0),
-          m_rootNode(new KDirModelDirNode(0, KFileItem())),
+    explicit KDirModelPrivate(KDirModel *model)
+        : q(model), m_dirLister(nullptr),
+          m_rootNode(new KDirModelDirNode(nullptr, KFileItem())),
           m_dropsAllowed(KDirModel::NoDrops), m_jobTransfersVisible(false)
     {
     }
@@ -190,7 +197,7 @@ public:
     void clear()
     {
         delete m_rootNode;
-        m_rootNode = new KDirModelDirNode(0, KFileItem());
+        m_rootNode = new KDirModelDirNode(nullptr, KFileItem());
     }
     // Emit expand for each parent and then return the
     // last known parent if there is no node for this url
@@ -221,11 +228,12 @@ public:
         return url;
     }
     void removeFromNodeHash(KDirModelNode *node, const QUrl &url);
+    void clearAllPreviews(KDirModelDirNode *node);
 #ifndef NDEBUG
     void dump();
 #endif
 
-    KDirModel *q;
+    KDirModel * const q;
     KDirLister *m_dirLister;
     KDirModelDirNode *m_rootNode;
     KDirModel::DropsAllowed m_dropsAllowed;
@@ -270,29 +278,29 @@ KDirModelNode *KDirModelPrivate::expandAllParentsUntil(const QUrl &_url) const /
 
     // Protocol mismatch? Don't even start comparing paths then. #171721
     if (url.scheme() != nodeUrl.scheme()) {
-        return 0;
+        return nullptr;
     }
 
     const QString pathStr = url.path(); // no trailing slash
     KDirModelDirNode *dirNode = m_rootNode;
 
     if (!pathStr.startsWith(nodeUrl.path())) {
-        return 0;
+        return nullptr;
     }
 
     for (;;) {
         QString nodePath = nodeUrl.path();
-        if (!nodePath.endsWith('/')) {
-            nodePath += '/';
+        if (!nodePath.endsWith(QLatin1Char('/'))) {
+            nodePath += QLatin1Char('/');
         }
         if (!pathStr.startsWith(nodePath)) {
-            qWarning() << "The kioslave for" << url.scheme() << "violates the hierarchy structure:"
+            qCWarning(KIO_WIDGETS) << "The kioslave for" << url.scheme() << "violates the hierarchy structure:"
                        << "I arrived at node" << nodePath << ", but" << pathStr << "does not start with that path.";
-            return 0;
+            return nullptr;
         }
 
         // E.g. pathStr is /a/b/c and nodePath is /a/. We want to find the node with url /a/b
-        const int nextSlash = pathStr.indexOf('/', nodePath.length());
+        const int nextSlash = pathStr.indexOf(QLatin1Char('/'), nodePath.length());
         const QString newPath = pathStr.left(nextSlash); // works even if nextSlash==-1
         nodeUrl.setPath(newPath);
         nodeUrl = nodeUrl.adjusted(QUrl::StripTrailingSlash); // #172508
@@ -321,11 +329,11 @@ KDirModelNode *KDirModelPrivate::expandAllParentsUntil(const QUrl &_url) const /
 #ifndef NDEBUG
 void KDirModelPrivate::dump()
 {
-    qDebug() << "Dumping contents of KDirModel" << q << "dirLister url:" << m_dirLister->url();
+    qCDebug(KIO_WIDGETS) << "Dumping contents of KDirModel" << q << "dirLister url:" << m_dirLister->url();
     QHashIterator<QUrl, KDirModelNode *> it(m_nodeHash);
     while (it.hasNext()) {
         it.next();
-        qDebug() << it.key() << it.value();
+        qDebug(KIO_WIDGETS) << it.key() << it.value();
     }
 }
 #endif
@@ -363,14 +371,14 @@ static QString debugIndex(const QModelIndex &index)
 {
     QString str;
     if (!index.isValid()) {
-        str = "[invalid index, i.e. root]";
+        str = QStringLiteral("[invalid index, i.e. root]");
     } else {
         KDirModelNode *node = static_cast<KDirModelNode *>(index.internalPointer());
-        str = "[index for " + node->item().url().toString();
+        str = QLatin1String("[index for ") + node->item().url().toString();
         if (index.column() > 0) {
-            str += ", column " + QString::number(index.column());
+            str += QLatin1String(", column ") + QString::number(index.column());
         }
-        str += ']';
+        str += QLatin1Char(']');
     }
     return str;
 }
@@ -396,16 +404,16 @@ void KDirModel::setDirLister(KDirLister *dirLister)
     }
     d->m_dirLister = dirLister;
     d->m_dirLister->setParent(this);
-    connect(d->m_dirLister, SIGNAL(itemsAdded(QUrl,KFileItemList)),
-            this, SLOT(_k_slotNewItems(QUrl,KFileItemList)));
-    connect(d->m_dirLister, SIGNAL(itemsDeleted(KFileItemList)),
-            this, SLOT(_k_slotDeleteItems(KFileItemList)));
-    connect(d->m_dirLister, SIGNAL(refreshItems(QList<QPair<KFileItem,KFileItem> >)),
-            this, SLOT(_k_slotRefreshItems(QList<QPair<KFileItem,KFileItem> >)));
-    connect(d->m_dirLister, SIGNAL(clear()),
-            this, SLOT(_k_slotClear()));
-    connect(d->m_dirLister, SIGNAL(redirection(QUrl,QUrl)),
-            this, SLOT(_k_slotRedirection(QUrl,QUrl)));
+    connect(d->m_dirLister, &KCoreDirLister::itemsAdded, this,
+        [this](const QUrl &dirUrl, const KFileItemList &items){d->_k_slotNewItems(dirUrl, items);} );
+    connect(d->m_dirLister, &KCoreDirLister::itemsDeleted, this,
+        [this](const KFileItemList &items){d->_k_slotDeleteItems(items);} );
+    connect(d->m_dirLister, &KCoreDirLister::refreshItems, this,
+        [this](const QList<QPair<KFileItem,KFileItem> > &items){d->_k_slotRefreshItems(items);} );
+    connect(d->m_dirLister, QOverload<>::of(&KCoreDirLister::clear), this,
+        [this](){d->_k_slotClear();} );
+    connect(d->m_dirLister, QOverload<const QUrl&, const QUrl&>::of(&KCoreDirLister::redirection), this,
+        [this](const QUrl &oldUrl, const QUrl &newUrl){d->_k_slotRedirection(oldUrl, newUrl);} );
 }
 
 KDirLister *KDirModel::dirLister() const
@@ -421,7 +429,7 @@ void KDirModelPrivate::_k_slotNewItems(const QUrl &directoryUrl, const KFileItem
     // If the directory containing the items wasn't found, then we have a big problem.
     // Are you calling KDirLister::openUrl(url,true,false)? Please use expandToUrl() instead.
     if (!result) {
-        qWarning() << "Items emitted in directory" << directoryUrl
+        qCWarning(KIO_WIDGETS) << "Items emitted in directory" << directoryUrl
                    << "but that directory isn't in KDirModel!"
                    << "Root directory:" << urlForNode(m_rootNode);
         Q_FOREACH (const KFileItem &item, items) {
@@ -452,6 +460,7 @@ void KDirModelPrivate::_k_slotNewItems(const QUrl &directoryUrl, const KFileItem
 
     QList<QModelIndex> emitExpandFor;
 
+    dirNode->m_childNodes.reserve(newRowCount);
     KFileItemList::const_iterator it = items.begin();
     KFileItemList::const_iterator end = items.end();
     for (; it != end; ++it) {
@@ -464,7 +473,7 @@ void KDirModelPrivate::_k_slotNewItems(const QUrl &directoryUrl, const KFileItem
         // not sure if/how it ever happened.
         //if (dirNode->m_childNodes.count() &&
         //    dirNode->m_childNodes.last()->item().name() == (*it).name()) {
-        //    qWarning() << "Already having" << (*it).name() << "in" << directoryUrl
+        //    qCWarning(KIO_WIDGETS) << "Already having" << (*it).name() << "in" << directoryUrl
         //             << "url=" << dirNode->m_childNodes.last()->item().url();
         //    abort();
         //}
@@ -513,7 +522,7 @@ void KDirModelPrivate::_k_slotDeleteItems(const KFileItemList &items)
     QUrl url = item.url();
     KDirModelNode *node = nodeForUrl(url); // O(depth)
     if (!node) {
-        qWarning() << "No node found for item that was just removed:" << url;
+        qCWarning(KIO_WIDGETS) << "No node found for item that was just removed:" << url;
         return;
     }
 
@@ -543,7 +552,7 @@ void KDirModelPrivate::_k_slotDeleteItems(const KFileItemList &items)
             url = item.url();
             node = nodeForUrl(url);
             if (!node) {
-                qWarning() << "No node found for item that was just removed:" << url;
+                qCWarning(KIO_WIDGETS) << "No node found for item that was just removed:" << url;
                 continue;
             }
             if (!node->parent()) {
@@ -554,7 +563,7 @@ void KDirModelPrivate::_k_slotDeleteItems(const KFileItemList &items)
         }
         rowNumbers.setBit(node->rowNumber(), 1); // O(n)
         removeFromNodeHash(node, url);
-        node = 0;
+        node = nullptr;
     }
 
     int start = -1;
@@ -682,12 +691,50 @@ void KDirModelPrivate::_k_slotClear()
 
 void KDirModelPrivate::_k_slotJobUrlsChanged(const QStringList &urlList)
 {
+    QStringList dirtyUrls;
+
+    std::set_symmetric_difference(urlList.begin(), urlList.end(),
+                                  m_allCurrentDestUrls.constBegin(), m_allCurrentDestUrls.constEnd(),
+                                  std::back_inserter(dirtyUrls));
+
     m_allCurrentDestUrls = urlList;
+
+    for (const QString &dirtyUrl : qAsConst(dirtyUrls)) {
+        if (KDirModelNode *node = nodeForUrl(QUrl(dirtyUrl))) {
+            const QModelIndex idx = indexForNode(node);
+            emit q->dataChanged(idx, idx, {KDirModel::HasJobRole});
+        }
+    }
+}
+
+void KDirModelPrivate::clearAllPreviews(KDirModelDirNode *dirNode)
+{
+    const int numRows = dirNode->m_childNodes.count();
+    if (numRows > 0) {
+        KDirModelNode *lastNode = nullptr;
+        for (KDirModelNode *node : qAsConst(dirNode->m_childNodes)) {
+            node->setPreview(QIcon());
+            //node->setPreview(QIcon::fromTheme(node->item().iconName()));
+            if (isDir(node)) {
+                // recurse into child dirs
+                clearAllPreviews(static_cast<KDirModelDirNode *>(node));
+            }
+            lastNode = node;
+        }
+        emit q->dataChanged(indexForNode(dirNode->m_childNodes.at(0), 0),  // O(1)
+                            indexForNode(lastNode, numRows - 1));          // O(1)
+    }
+
+}
+
+void KDirModel::clearAllPreviews()
+{
+    d->clearAllPreviews(d->m_rootNode);
 }
 
 void KDirModel::itemChanged(const QModelIndex &index)
 {
-    // This method is really a itemMimeTypeChanged(), it's mostly called by KMimeTypeResolver.
+    // This method is really a itemMimeTypeChanged(), it's mostly called by KFilePreviewGenerator.
     // When the mimetype is determined, clear the old "preview" (could be
     // mimetype dependent like when cutting files, #164185)
     KDirModelNode *node = d->nodeForIndex(index);
@@ -774,7 +821,7 @@ QVariant KDirModel::data(const QModelIndex &index, int role) const
 //                        count = dir.entryList(QDir::AllEntries|QDir::NoDotAndDotDot|QDir::System).count();
 #ifdef Q_OS_WIN
                         QString s = path + QLatin1String("\\*.*");
-                        s.replace('/', '\\');
+                        s.replace(QLatin1Char('/'), QLatin1Char('\\'));
                         count = 0;
                         WIN32_FIND_DATA findData;
                         HANDLE hFile = FindFirstFile((LPWSTR)s.utf16(), &findData);
@@ -791,10 +838,10 @@ QVariant KDirModel::data(const QModelIndex &index, int role) const
                             FindClose(hFile);
                         }
 #else
-                        DIR *dir = QT_OPENDIR(QFile::encodeName(path));
+                        DIR *dir = QT_OPENDIR(QFile::encodeName(path).constData());
                         if (dir) {
                             count = 0;
-                            QT_DIRENT *dirEntry = 0;
+                            QT_DIRENT *dirEntry = nullptr;
                             while ((dirEntry = QT_READDIR(dir))) {
                                 if (dirEntry->d_name[0] == '.') {
                                     if (dirEntry->d_name[1] == '\0') { // skip "."
@@ -830,7 +877,7 @@ QVariant KDirModel::data(const QModelIndex &index, int role) const
 void KDirModel::sort(int column, Qt::SortOrder order)
 {
     // Not implemented - we should probably use QSortFilterProxyModel instead.
-    return QAbstractItemModel::sort(column, order);
+    QAbstractItemModel::sort(column, order);
 }
 
 bool KDirModel::setData(const QModelIndex &index, const QVariant &value, int role)
@@ -847,8 +894,8 @@ bool KDirModel::setData(const QModelIndex &index, const QVariant &value, int rol
             }
             QUrl newUrl = item.url().adjusted(QUrl::RemoveFilename);
             newUrl.setPath(newUrl.path() + KIO::encodeFileName(newName));
-            KIO::Job *job = KIO::moveAs(item.url(), newUrl, item.url().isLocalFile() ? KIO::HideProgressInfo : KIO::DefaultFlags);
-            job->ui()->setAutoErrorHandlingEnabled(true);
+            KIO::Job *job = KIO::rename(item.url(), newUrl, item.url().isLocalFile() ? KIO::HideProgressInfo : KIO::DefaultFlags);
+            job->uiDelegate()->setAutoErrorHandlingEnabled(true);
             // undo handling
             KIO::FileUndoManager::self()->recordJob(KIO::FileUndoManager::Rename, QList<QUrl>() << item.url(), newUrl, job);
             return true;
@@ -928,11 +975,6 @@ QModelIndex KDirModel::sibling(int row, int column, const QModelIndex &index) co
     return QModelIndex();
 }
 
-static bool lessThan(const QUrl &left, const QUrl &right)
-{
-    return left.toString().compare(right.toString()) < 0;
-}
-
 void KDirModel::requestSequenceIcon(const QModelIndex &index, int sequenceIndex)
 {
     emit needSequenceIcon(index, sequenceIndex);
@@ -958,12 +1000,12 @@ bool KDirModel::jobTransfersVisible() const
 
 QList<QUrl> KDirModel::simplifiedUrlList(const QList<QUrl> &urls)
 {
-    if (!urls.count()) {
+    if (urls.isEmpty()) {
         return urls;
     }
 
     QList<QUrl> ret(urls);
-    qSort(ret.begin(), ret.end(), lessThan);
+    std::sort(ret.begin(), ret.end());
 
     QList<QUrl>::iterator it = ret.begin();
     QUrl url = *it;
@@ -988,6 +1030,8 @@ QStringList KDirModel::mimeTypes() const
 QMimeData *KDirModel::mimeData(const QModelIndexList &indexes) const
 {
     QList<QUrl> urls, mostLocalUrls;
+    urls.reserve(indexes.size());
+    mostLocalUrls.reserve(indexes.size());
     bool canUseMostLocalUrls = true;
     foreach (const QModelIndex &index, indexes) {
         const KFileItem &item = d->nodeForIndex(index)->item();
@@ -1052,13 +1096,13 @@ QModelIndex KDirModel::index(int row, int column, const QModelIndex &parent) con
 {
     KDirModelNode *parentNode = d->nodeForIndex(parent); // O(1)
     Q_ASSERT(parentNode);
-    Q_ASSERT(d->isDir(parentNode));
-    KDirModelNode *childNode = static_cast<KDirModelDirNode *>(parentNode)->m_childNodes.value(row); // O(1)
-    if (childNode) {
-        return createIndex(row, column, childNode);
-    } else {
-        return QModelIndex();
+    if (d->isDir(parentNode)) {
+        KDirModelNode *childNode = static_cast<KDirModelDirNode *>(parentNode)->m_childNodes.value(row); // O(1)
+        if (childNode) {
+            return createIndex(row, column, childNode);
+        }
     }
+    return QModelIndex();
 }
 
 QVariant KDirModel::headerData(int section, Qt::Orientation orientation, int role) const
@@ -1114,7 +1158,7 @@ Qt::ItemFlags KDirModel::flags(const QModelIndex &index) const
         } else {
             KFileItem item = itemForIndex(index);
             if (item.isNull()) {
-                qWarning() << "Invalid item returned for index";
+                qCWarning(KIO_WIDGETS) << "Invalid item returned for index";
             } else if (item.isDir()) {
                 if (d->m_dropsAllowed & DropOnDirectory) {
                     f |= Qt::ItemIsDropEnabled;
@@ -1125,7 +1169,7 @@ Qt::ItemFlags KDirModel::flags(const QModelIndex &index) const
                 } else if (d->m_dropsAllowed & DropOnLocalExecutable) {
                     if (!item.localPath().isEmpty()) {
                         // Desktop file?
-                        if (item.determineMimeType().inherits("application/x-desktop")) {
+                        if (item.determineMimeType().inherits(QStringLiteral("application/x-desktop"))) {
                             f |= Qt::ItemIsDropEnabled;
                         }
                         // Executable, shell script ... ?
@@ -1168,7 +1212,9 @@ void KDirModel::fetchMore(const QModelIndex &parent)
 
     KFileItem parentItem = parentNode->item();
     Q_ASSERT(!parentItem.isNull());
-    Q_ASSERT(parentItem.isDir());
+    if (!parentItem.isDir()) {
+        return;
+    }
     KDirModelDirNode *dirNode = static_cast<KDirModelDirNode *>(parentNode);
     if (dirNode->isPopulated()) {
         return;
