@@ -22,9 +22,10 @@
 #define _KDIRLISTERTEST_GUI_H_
 
 #include <QWidget>
-#include <QtCore/QString>
+#include <QString>
 #include <QUrl>
 
+#include <kdirlister.h>
 #include <kfileitem.h>
 
 #include <iostream>
